package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.entity.MusicCollect;
import com.ruoyi.common.core.domain.entity.UserCollect;

import java.util.List;

/**
 * 用户收藏音乐Service接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
public interface IUserCollectService 
{
    /**
     * 查询用户收藏音乐
     * 
     * @param id 用户收藏音乐主键
     * @return 用户收藏音乐
     */
    public UserCollect selectUserCollectById(Long id);

    /**
     * 查询用户收藏音乐列表
     * 
     * @param userCollect 用户收藏音乐
     * @return 用户收藏音乐集合
     */
    public List<UserCollect> selectUserCollectList(UserCollect userCollect);

    /**
     * 新增用户收藏音乐
     * 
     * @param userCollect 用户收藏音乐
     * @return 结果
     */
    public int insertUserCollect(UserCollect userCollect);

    /**
     * 修改用户收藏音乐
     * 
     * @param userCollect 用户收藏音乐
     * @return 结果
     */
    public int updateUserCollect(UserCollect userCollect);

    /**
     * 批量删除用户收藏音乐
     * 
     * @param ids 需要删除的用户收藏音乐主键集合
     * @return 结果
     */
    public int deleteUserCollectByIds(Long[] ids);

    /**
     * 删除用户收藏音乐信息
     * 
     * @param id 用户收藏音乐主键
     * @return 结果
     */
    public int deleteUserCollectById(Long id);

    int cancelBindMusic(MusicCollect musicCollect);
}
